@@ -9,25 +9,21 @@ use Doctrine\Persistence\Mapping\ClassMetadata;
 /**
  * The PHPDriver includes php files which just populate ClassMetadataInfo
  * instances with plain PHP code.
+ *
+ * @template-extends FileDriver<ClassMetadata<object>>
  */
 class PHPDriver extends FileDriver
 {
-    /**
-     * @var ClassMetadata
-     * @psalm-var ClassMetadata<object>
-     */
-    protected $metadata;
+    /** @phpstan-var ClassMetadata<object> */
+    protected ClassMetadata $metadata;
 
     /** @param string|array<int, string>|FileLocator $locator */
-    public function __construct($locator)
+    public function __construct(string|array|FileLocator $locator)
     {
         parent::__construct($locator, '.php');
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function loadMetadataForClass(string $className, ClassMetadata $metadata)
+    public function loadMetadataForClass(string $className, ClassMetadata $metadata): void
     {
         $this->metadata = $metadata;
 
@@ -37,7 +33,7 @@ class PHPDriver extends FileDriver
     /**
      * {@inheritDoc}
      */
-    protected function loadMappingFile(string $file)
+    protected function loadMappingFile(string $file): array
     {
         $metadata = $this->metadata;
         include $file;
